# All-In Python Package

The `allinpy` package contains useful utilities for plotting in Python and general utilities relevant to multiple projects.

⚠️ This is an early-stage version of `allinpy`.
Expect ongoing development and improvements. Contributions and feedback are welcome!

## Questions?

For questions, please get in touch with me: [rasmusb@zedat.fu-berlin.de](rasmusb@zedat.fu-berlin.de)

## Built With

* [Python](https://www.python.org)

## Author

**Rasmus Bruckner** - [GitHub](https://github.com/rasmusbruckner) - [Freie Universität Berlin](https://www.ewi-psy.fu-berlin.de/en/einrichtungen/arbeitsbereiche/neural_dyn_of_vis_cog/learning-lab/team/bruckner/index.html)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
